"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const grayMatter = require("gray-matter");
const pify = require("pify");
const hasha = require("hasha");
const stableStringify = require("json-stable-stringify");
const remark = require('remark');
const slug = require('remark-slug');
const hljs = require('remark-highlight.js');
const html = require('remark-html');
const emoji = require('remark-gemoji-to-emoji');
const autolinkHeadings = require('@rigor789/remark-autolink-headings');
const inlineLinks = require('remark-inline-links');
const renderer = remark()
    .use(slug)
    .use(autolinkHeadings, { behaviour: 'wrap' })
    .use(inlineLinks)
    .use(emoji)
    .use([hljs, html], { sanitize: false });
async function markdowner(markdownString, opts) {
    const hash = makeHash(markdownString, opts);
    const defaults = {
        frontmatter: false
    };
    opts = Object.assign(defaults, opts);
    let data = {};
    let content = markdownString;
    // Check the cache for preprocessed markdown
    if (opts.cache) {
        let existing = false;
        try {
            existing = await opts.cache.get(hash);
        }
        catch (err) {
            if (!err.notFound)
                console.error(err);
        }
        if (existing)
            return existing;
    }
    if (opts.frontmatter) {
        const parsed = grayMatter(markdownString);
        data = parsed.data;
        content = parsed.content;
    }
    const md = await pify(renderer.process)(content);
    Object.assign(data, { content: md.contents });
    // @ts-ignore `Put` not found in Map<> | Save processed markdown in cache
    if (opts.cache)
        await opts.cache.put(hash, data);
    return data;
}
exports.markdowner = markdowner;
// Create a unique hash from the given input (markdown + options object)
function makeHash(markdownString, opts) {
    // Copy existing opts object to avoid mutation
    const hashableOpts = Object.assign({}, opts);
    // Ignore `cache` prop when creating hash
    delete hashableOpts.cache;
    // Deterministic stringifier gets a consistent hash from stringified results
    // object keys are sorted to ensure {a:1, b:2} has the same hash as {b:2, a:1}
    // empty object should become an empty string, not {}
    const optsString = Object.keys(hashableOpts).length ? stableStringify(hashableOpts) : '';
    return hasha(markdownString + optsString);
}
//# sourceMappingURL=index.js.map